@@ -1,10 +1,19 @@
+##
+# name:      worky
+# abstract:  For when your code no worky
+# author:    Ingy döt Net <ingy@ingy.net>
+# license:   perl
+# copyright: 2006, 2011
+# see:
+# - orz
+
+use 5.008003;
 package worky;
-use 5.006001;
 use strict;
 use warnings;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
-use orz -base;
+use orz 0.13 -base;
 
 sub pmc_use_means_no { 1 }
 
@@ -17,10 +26,6 @@ sub pmc_compile {
 
 1;
 
-=head1 NAME
-
-worky - For when your code no worky
-
 =head1 SYNOPSIS
 
     {
@@ -32,18 +37,3 @@ worky - For when your code no worky
 =head1 DESCRIPTION
 
 When your code no worky, just say so.
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2006. Ingy döt Net. All rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See L<http://www.perl.com/perl/misc/Artistic.html>
-
-=cut
